TryCountExt

Trait TryCountExt 

pub trait TryCountExt: TryStream + Sized {
    // Provided method
    fn try_count(self) -> impl Future<Output = Result<usize, Self::Error>> { ... }
}

Provided Methods

fn try_count(self) -> impl Future<Output = Result<usize, Self::Error>>

A terminal operation that counts the number of Ok items in the Stream, erroring if an Err Result is ever encountered

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<S> TryCountExt for S
where S: TryStream + Sized,